"""
        Python bindings for SRF Segments
        -------------------------------
        .. currentmodule:: segment
        .. autosummary::
           :toctree: _generate
    """
from __future__ import annotations
import srf.core.segment
import typing
from srf.core.node import SegmentObject
import srf.core.common
import srf.core.node
import srf.core.subscriber

__all__ = [
    "Builder",
    "Definition",
    "ModuleRegistry",
    "SegmentModule",
    "SegmentObject"
]


class Builder():
    def get_egress(self, name: str) -> srf.core.node.SegmentObject: ...
    def get_ingress(self, name: str) -> srf.core.node.SegmentObject: ...
    def init_module(self, module: SegmentModule) -> None: ...
    def load_module(self, module_id: str, registry_namespace: str, module_name: str, module_config: dict) -> SegmentModule: ...
    @typing.overload
    def make_edge(self, arg0: srf.core.node.SegmentObject, arg1: srf.core.node.SegmentObject) -> None: ...
    @typing.overload
    def make_edge(self, source: srf.core.node.SegmentObject, sink: srf.core.node.SegmentObject) -> None: ...
    def make_node(self, arg0: str, arg1: typing.Callable[[object], object]) -> srf.core.node.SegmentObject: ...
    def make_node_full(self, arg0: str, arg1: typing.Callable[[srf.core.subscriber.Observable, srf.core.subscriber.Subscriber], None]) -> srf.core.node.SegmentObject: ...
    def make_sink(self, arg0: str, arg1: typing.Callable[[object], None], arg2: typing.Callable[[object], None], arg3: typing.Callable[[], None]) -> srf.core.node.SegmentObject: ...
    @typing.overload
    def make_source(self, arg0: str, arg1: function) -> srf.core.node.SegmentObject: ...
    @typing.overload
    def make_source(self, arg0: str, arg1: typing.Iterable) -> srf.core.node.SegmentObject: ...
    @typing.overload
    def make_source(self, arg0: str, arg1: typing.Iterator) -> srf.core.node.SegmentObject: ...
    def register_module_input(self, input_name: str, object: srf.core.node.SegmentObject) -> None: ...
    def register_module_output(self, output_name: str, object: srf.core.node.SegmentObject) -> None: ...
    pass
class Definition():
    pass
class ModuleRegistry():
    @staticmethod
    def contains(name: str, registry_namespace: str) -> bool: ...
    @staticmethod
    def contains_namespace(registry_namespace: str) -> bool: ...
    @staticmethod
    def get_module_constructor(name: str, registry_namespace: str) -> cpp_function: ...
    @staticmethod
    def is_version_compatible(release_version: typing.List[int]) -> bool: ...
    @staticmethod
    @typing.overload
    def register_module(name: str, registry_namespace: str, release_version: typing.List[int], fn_constructor: typing.Callable[[Builder], None]) -> None: ...
    @staticmethod
    @typing.overload
    def register_module(name: str, release_version: typing.List[int], fn_constructor: typing.Callable[[Builder], None]) -> None: ...
    @staticmethod
    def registered_modules() -> typing.Dict[str, typing.List[str]]: ...
    @staticmethod
    def unregister_module(name: str, registry_namespace: str, optional: bool = True) -> None: ...
    pass
class SegmentModule():
    def component_prefix(self) -> str: ...
    def config(self) -> dict: ...
    def input_ids(self) -> typing.List[str]: ...
    def input_port(self, input_id: str) -> srf.core.node.SegmentObject: ...
    def input_ports(self) -> typing.Dict[str, srf.core.node.SegmentObject]: ...
    def module_type_name(self) -> str: ...
    def name(self) -> str: ...
    def output_ids(self) -> typing.List[str]: ...
    def output_port(self, output_id: str) -> srf.core.node.SegmentObject: ...
    def output_ports(self) -> typing.Dict[str, srf.core.node.SegmentObject]: ...
    pass
__version__ = '22.11.0'
